@@ -58,7 +58,7 @@ class ConsumerStrategyFactory(ProcessingStrategyFactory[TPayload]):
         input_block_size: Optional[int],
         output_block_size: Optional[int],
         initialize_parallel_transform: Optional[Callable[[], None]] = None,
-        parallel_collect_step: Optional[bool] = False,
+        parallel_collect: bool = False,
     ) -> None:
         self.__prefilter = prefilter
         self.__process_message = process_message
@@ -82,7 +82,7 @@ class ConsumerStrategyFactory(ProcessingStrategyFactory[TPayload]):
         self.__input_block_size = input_block_size
         self.__output_block_size = output_block_size
         self.__initialize_parallel_transform = initialize_parallel_transform
-        self.__parallel_collect_step = parallel_collect_step
+        self.__parallel_collect = parallel_collect
 
     def __should_accept(self, message: Message[TPayload]) -> bool:
         assert self.__prefilter is not None
@@ -95,7 +95,7 @@ class ConsumerStrategyFactory(ProcessingStrategyFactory[TPayload]):
             ParallelCollectStep(
                 self.__collector, commit, self.__max_batch_size, self.__max_batch_time
             )
-            if self.__parallel_collect_step
+            if self.__parallel_collect
             else CollectStep(
                 self.__collector,
                 commit,
